@@ -1,4 +1,4 @@
-# $Id: sympasoap.pm 10860 2014-06-06 09:33:42Z david.verdin $
+# $Id: sympasoap.pm 11154 2014-07-12 03:31:32Z sikeda $
 
 # Sympa - SYsteme de Multi-Postage Automatique
 #
@@ -562,12 +562,19 @@ sub createList {
 	    ->faultdetail("Missing required parameter(s) : $reject");	
     }
     # check authorization
-    my $result = &Scenario::request_action('create_list','md5',$robot,
-					 {'sender' => $sender,
-					  'remote_host' => $ENV{'REMOTE_HOST'},
-					  'remote_addr' =>  $ENV{'REMOTE_ADDR'},
-					  'remote_application_name' =>  $ENV{'remote_application_name'} }
-					 );
+    my $result = &Scenario::request_action('create_list', 'md5', $robot,
+		{
+			'sender' => $sender,
+			'candidate_listname' => $listname,
+			'candidate_subject' => $subject,
+			'candidate_template' => $template,
+			'candidate_info' => $description,
+			'candidate_topics' => $topics,
+			'remote_host' => $ENV{'REMOTE_HOST'},
+			'remote_addr' =>  $ENV{'REMOTE_ADDR'},
+			'remote_application_name' =>  $ENV{'remote_application_name'}
+		}
+	);
     my $r_action;
     my $reason;
     if (ref($result) eq 'HASH') {
@@ -768,7 +775,22 @@ sub add {
 	$u->{'email'} = $email;
 	$u->{'gecos'} = $gecos || $u2->{'gecos'};
 	$u->{'date'} = $u->{'update_date'} = time;
-	$u->{'password'} = $u2->{'password'} || &tools::tmp_passwd($email) ;
+
+	# If Password validation is enabled check the submitted password 
+  # against the site configured constraints
+	if ($u2->{'password'}) {
+		if (my $result = &tools::password_validation($u->{'password'})) {
+			&Log::do_log('info', 'add %s@%s %s from %s : scenario error', $listname,$robot,$email,$sender);
+			die SOAP::Fault->faultcode('Server')
+		    ->faultstring('Weak password')
+				->faultdetail('Weak password: '. $result);
+		}
+		$u->{'password'} = $u2->{'password'};
+	}
+	else {
+		$u->{'password'} = &tools::tmp_passwd($email) ;
+	}
+
 	$u->{'lang'} = $u2->{'lang'} || $list->{'admin'}{'lang'};
 	
 	unless ($list->add_user($u)) {
